#
# This file is part of Data-Importer
#
# This software is copyright (c) 2014 by Kaare Rasmussen.
#
# This is free software; you can redistribute it and/or modify it under
# the same terms as the Perl 5 programming language system itself.
#
package Test::Schema::Result::Product;
use base qw/DBIx::Class::Core/;
__PACKAGE__->table('product');
__PACKAGE__->add_columns(qw/ id name ingredients qty /);
__PACKAGE__->set_primary_key('id');

1;
