#
# This file is part of Data-Importer
#
# This software is copyright (c) 2014 by Kaare Rasmussen.
#
# This is free software; you can redistribute it and/or modify it under
# the same terms as the Perl 5 programming language system itself.
#
package Test::Schema;
use base qw/DBIx::Class::Schema/;
__PACKAGE__->load_namespaces;

1;
